| Title: | Holding the Database for the 'extrafont' Package |
|---|---|
| Description: | It is meant to be used with the 'extrafont' package. The 'extrafont' package contains the code to install and use fonts, while the 'extrafontdb' package contains the font database. |
| Authors: | Winston Chang [aut], Frederic Bertrand [cre]
|
| Maintainer: | Frederic Bertrand <[email protected]> |
| License: | GPL-2 |
| Version: | 1.1 |
| Built: | 2026-05-27 08:15:16 UTC |
| Source: | https://github.com/fbertran/extrafontdb |