Welcome to ClientVPS Mirrors

Help for package extrafontdb
Type: Package
Title: Holding the Database for the 'extrafont' Package
Version: 1.1
Date: 2025-09-25
Depends: R (≥ 2.14)
Suggests: testthat (≥ 3.0.0)
Author: Winston Chang [aut], Frederic Bertrand ORCID iD [cre]
Maintainer: Frederic Bertrand <frederic.bertrand@lecnam.net>
Description: It is meant to be used with the 'extrafont' package. The 'extrafont' package contains the code to install and use fonts, while the 'extrafontdb' package contains the font database.
License: GPL-2
LazyLoad: yes
NeedsCompilation: no
URL: https://github.com/fbertran/extrafontdb
BugReports: https://github.com/fbertran/extrafontdb/issues
RoxygenNote: 7.3.3
Encoding: UTF-8
Config/testthat/edition: 3
Collate: 'extrafontdb.r'
Packaged: 2025-09-26 09:02:45 UTC; bertran7
Repository: CRAN
Date/Publication: 2025-09-28 13:10:02 UTC

extrafontdb: Holding the Database for the 'extrafont' Package

Description

It is meant to be used with the 'extrafont' package. The 'extrafont' package contains the code to install and use fonts, while the 'extrafontdb' package contains the font database.

Author(s)

Maintainer: Frederic Bertrand frederic.bertrand@lecnam.net (ORCID)

Authors:

See Also

Useful links:

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.